.. _api-index: 

####################
  The RLPy API
####################

Base Classes
############

.. toctree::
   :maxdepth: 1

   experiment.rst
   agent.rst
   policy.rst
   representation.rst
   mdp_solver.rst
   domain.rst

Domains
#######

.. toctree::
    :maxdepth: 1

    acrobot.rst
    bicycle.rst
    domains_misc.rst
    finite_cartpole.rst
    infinite_cartpole.rst

Helper modules
##############

.. toctree::
    :maxdepth: 1

    runtools.rst
